%
%   simstep_fdbk.M    Function to perform simulation step with movement  
%                 of the BOI using point kinetics with feedbacks included
%
%   Does point kinetics simulation over given duration with a possible blade
%   movement at the beginning of the simulation step. This version includes
%   temperature and xenon feedbacks...
%
%   xo = initial state at start of interval
%   rho0 = initial rho at start of interval
%   Q = source level
%   zlocs = [start end] location of RegBlade
%   tstart = actual global start time (simulation is done from 0 to tdur)
%   tdur = simulation time for this step
%   rate = speed of RegBlade (should be positive - direction determined by zlocs)
%   boi,yr define the blade of interest and the year for the worth curves
%   opt_alfTf = option for choice of fuel temp coeff
%
%   File prepared by J. R. White, UMass-Lowell (March 2013)
%

      function [t,x,z,rhoex] = simstep_fdbk(xo,rho0,Q,zlocs,tstrt,tdur,rate, ...
                              tT,Tint,Tcr,Tfr,cfac,mode,boi,yr,opt_alfTf)
      tol = 1e-5;  options = odeset('RelTol',tol);   % set tolerance for ode solver
      [Be,B,Gt,lam,td,S,kappa,nu] = kinetics_data(); % set kinetics parameters
      dt = 1;  t = tstrt:dt:tstrt+tdur;  
      ftx = @(t,x) pkeqns_rampb_fdbk(t,x,rho0,Q,Be,Gt,B,lam,kappa,nu, ...
                   rate,zlocs,tstrt,tT,Tint,Tcr,Tfr,cfac,mode,boi,yr,opt_alfTf);
      [t,x] = ode15s(ftx,t,xo,options);
      speed = rate; 
      if zlocs(2) < zlocs(1), speed = -speed;  end
      z = zlocs(1)+speed*(t-tstrt);  
      if speed > 0, z(z > zlocs(2)) = zlocs(2);  end
      if speed < 0, z(z < zlocs(2)) = zlocs(2);  end
      rhob = bworth(z,boi,yr)-bworth(z(1),boi,yr);  rhob = rhob/100;  % blade Dk/k
      rhoex = rho0+rhob;    % total external reactivity
%
%   end of function